@@ -32,7 +32,7 @@ class FileFinder : public KLineEdit
     Q_OBJECT
 
 public:
-    explicit FileFinder( QWidget *parent=0 );
+    explicit FileFinder(QWidget* parent = nullptr);
     ~FileFinder();
 
     KUrlCompletion *completion() {
@@ -41,16 +41,15 @@ public:
 
     virtual void hide();
 
-signals:
+Q_SIGNALS:
     void enterDir( const QString& );
 
 protected:
     virtual void focusOutEvent( QFocusEvent * ) override;
     virtual void keyPressEvent( QKeyEvent * ) override;
 
-private slots:
+private Q_SLOTS:
     void slotAccept( const QString& );
-
 };
 
 #endif // FILEFINDER_H
