@@ -21,7 +21,7 @@
 
 #include <QWidget>
 
-class KuickData;
+class KuickConfig;
 namespace Ui { class GeneralWidget; }
 
 
@@ -30,18 +30,18 @@ class GeneralWidget : public QWidget
     Q_OBJECT
 
 public:
-    GeneralWidget( QWidget *parent );
-    ~GeneralWidget();
+    explicit GeneralWidget(QWidget *parent);
+    virtual ~GeneralWidget();
 
-    void 	loadSettings( const KuickData& data );
-    void 	applySettings( KuickData& data );
+    void 		loadSettings(const KuickConfig* config = nullptr);
+    void 		applySettings();
 
 private:
     Ui::GeneralWidget* ui;
 
-private slots:
+private Q_SLOTS:
     void 	useOwnPalette();
-    void slotURLClicked( const QString & );
+    void slotURLClicked();
 
 };
 
