@@ -19,7 +19,7 @@
 #ifndef IMAGEWINDOW_H
 #define IMAGEWINDOW_H
 
-#include <QString>
+#include <qurl.h>
 
 #include "imlibwidget.h"
 
@@ -34,7 +34,6 @@ class QMenu;
 class QMouseEvent;
 class QResizeEvent;
 class QSize;
-class QUrl;
 class QWheelEvent;
 class QWidget;
 class KuickFile;
@@ -45,20 +44,15 @@ class ImageWindow : public ImlibWidget
   Q_OBJECT
 
 public:
-  ImageWindow( ImData *_idata, ImlibData *id, QWidget *parent=0 );
-  ImageWindow( ImData *_idata=0, QWidget *parent=0 );
-  ~ImageWindow();
+  ImageWindow(QWidget *parent = nullptr);
+  virtual ~ImageWindow() = default;
 
   bool 		showNextImage( KuickFile * file );
   bool 		showNextImage( const QUrl& url );
-  void 		scrollImage( int, int, bool restrict=true );
+  void 		scrollImage( int x, int y );
   void		setFullscreen( bool );
   bool 		isFullscreen() 	const { return myIsFullscreen; }
 
-  void          addBrightness( int );
-  void 		addContrast( int );
-  void 		addGamma( int );
-
   void 		updateActions();
 
   KActionCollection * actionCollection() const { return m_actions; }
@@ -70,10 +64,14 @@ public:
   void resizeOptimal( int w, int h );
   void autoScale( KuickImage *kuim );
   virtual bool autoRotate(KuickImage *kuim) override;
+  void safeMoveWindow(const QPoint& pos);
+  void safeMoveWindow(int x, int y) { safeMoveWindow(QPoint(x, y)); }
+  void safeResizeWindow(const QSize& size);
+  void safeResizeWindow(int width, int height) { safeResizeWindow(QSize(width, height)); }
 
   bool          saveImage( const QUrl& dest, bool keepOriginalSize );
 
-public slots:
+public Q_SLOTS:
   void 		zoomIn();
   void 		zoomOut();
   void          moreBrightness();
@@ -92,14 +90,16 @@ public slots:
   void 		imageDelete();
   void 		imageTrash();
 
-signals:
+Q_SIGNALS:
   void 		sigFocusWindow( ImageWindow * );
   // go advance images back/forth
   void          requestImage( ImageWindow *, int advance );
   void          deleteImage(ImageWindow *viewer);
   void          trashImage(ImageWindow *viewer);
+  void          duplicateWindow(const QUrl &url);
   void		nextSlideRequested();
   void		prevSlideRequested();
+  void          showFileBrowser(const QUrl &url);
 
 protected:
 
@@ -146,18 +146,15 @@ protected:
   QMenu    *viewerMenu, *gammaMenu, *brightnessMenu, *contrastMenu;
   QWidget       *transWidget;
 
-
-protected slots:
-  void 		saveImage();
-  void          slotRequestNext()           { emit requestImage( this, +1 ); }
-  void          slotRequestPrevious()       { emit requestImage( this, -1 ); }
+protected Q_SLOTS:
+  void 		slotSaveImage();
   void          reload();
   void          slotProperties();
   void          pauseSlideShow();
   virtual void  setBusyCursor();
   virtual void  restoreCursor();
 
-signals:
+Q_SIGNALS:
   void          pauseSlideShowSignal();
 
 private:
@@ -169,8 +166,7 @@ private:
   bool          isCursorHidden() const;
 
   bool 		myIsFullscreen;
-  int           m_numHeads;
-  QString   m_saveDirectory;
+  QUrl          m_saveDirectory;
 
   KActionCollection *m_actions;
 
