@@ -12,87 +12,45 @@
 #ifndef IMLIBWIDGET_H
 #define IMLIBWIDGET_H
 
-#include <QCursor>
-#include <QObject>
-#include <QWidget>
-#include <QX11Info>
+#include "imlib.h"
 
-#include "imlib-wrapper.h"
+#include <QScrollArea>
 
-#include "imdata.h"
-#include "kuickdata.h"
+#include "kuickconfig.h"
 
 class QCloseEvent;
 class QColor;
 class QUrl;
 class KuickFile;
 class KuickImage;
+class QLabel;
+class ImageCache;
 
 
-class ImageCache : public QObject
-{
-  Q_OBJECT
-
-public:
-  ImageCache( ImlibData *id, int maxImages=1 );
-  ~ImageCache();
-
-  void 			setMaxImages( int maxImages );
-  int 			maxImages() 		const { return myMaxImages; }
-
-  KuickImage *		getKuimage( KuickFile * file );
-  KuickImage *		loadImage( KuickFile *file, ImlibColorModifier );
-  //  KuickImage *		find( const QString& filename );
-
-private:
-  ImlibImage *		loadImageWithQt( const QString& filename ) const;
-
-  int 			myMaxImages;
-  QList<KuickFile*>	fileList;
-  QList<KuickImage*>	kuickList;
-  //  QPtrList<ImlibImage>	imList;
-  ImlibData * 		myId;
-  int 			idleCount;
-
-private slots:
-  void 			slotBusy();
-  void 			slotIdle();
-
-signals:
-  void			sigBusy();
-  void 			sigIdle();
-
-};
-
-
-// ------------------------------------------
-
-
-class ImlibWidget : public QWidget
+class ImlibWidget : public QScrollArea
 {
   Q_OBJECT
 
 public:
 
-  ImlibWidget( ImData *_idata=0, QWidget *parent=0 );
-  ImlibWidget( ImData *_idata, ImlibData *id, QWidget *parent=0 );
+  explicit ImlibWidget(QWidget *parent = nullptr);
   virtual ~ImlibWidget();
 
+  QSize sizeHint() const override;
+
   QUrl          url()                   const;
   KuickFile *   currentFile()           const;
   bool		loadImage( KuickFile * file);
   bool		loadImage( const QUrl& url );
   bool 		cacheImage( const QUrl& url );
   void 		zoomImage( float );
-  void 		setBrightness( int );
-  void 		setContrast( int );
-  void 		setGamma( int );
   void 		setRotation( Rotation );
   void 		setFlipMode( int mode );
 
-  int 		brightness()     const;
-  int 		contrast()		 const;
-  int 		gamma() 		 const;
+  void 		stepBrightness(int b);
+  void 		stepContrast(int c);
+  void 		stepGamma(int g);
+
   Rotation 	rotation() 		 const;
   FlipMode	flipMode() 		 const;
 
@@ -101,22 +59,20 @@ public:
 
   void 		setAutoRender( bool enable )   { isAutoRendering = enable;}
   bool 		isAutoRenderEnabled() 	const  { return isAutoRendering;  }
-  void 		setMaxImageCache( int );
   int 		maxImageCache() 	const  { return myMaxImageCache;  }
   const QColor& backgroundColor() 	const;
   void 		setBackgroundColor( const QColor& );
 
+  void setUseModifications(bool enable = true);
+  void initModifications();
+
   /**
    * @return true if auto-rotation is not possible, e.g. because no metadata
    * about orientation is available
    */
   virtual bool  autoRotate( KuickImage *kuim );
 
-  ImlibData*	getImlibData() const 	       { return id; 		  }
-
-//  virtual void  reparent( QWidget* parent, Qt::WFlags f, const QPoint& p, bool showIt = false );
-
-public slots:
+public Q_SLOTS:
   void 		rotate90();
   void 		rotate270();
   void 		rotate180();
@@ -125,13 +81,7 @@ public slots:
   void 		showImageOriginalSize();
   inline void 	updateImage() 		{ updateWidget( true ); }
 
-
 protected:
-  Display *	    getX11Display() const { return QX11Info::display(); }
-  int getX11Screen() const;
-  KuickImage *	loadImageInternal( KuickFile * file );
-  void 			showImage();
-  void          setImageModifier();
   void 		    rotate( int );
   void 		    updateWidget( bool geometryUpdate=true );
   virtual void 	updateGeometry( int width, int height );
@@ -146,36 +96,36 @@ protected:
       updateWidget( geometryUpdate );
   }
 
-  bool		stillResizing, deleteImData, deleteImlibData;
-  bool          imlibModifierChanged;
-
   KuickImage 	*m_kuim;
   ImageCache 	*imageCache;
-  ImlibData     *id;
-  ImData    	*idata;
-  Window        win;
-  ImlibColorModifier mod;
+
+private:
+  ImageModifiers myModifier;
 
   KuickFile *m_kuickFile;
   QCursor m_oldCursor;
 
-  static const int ImlibOffset;
-
-
 private:
-  void 		init();
+  void init();
+  KuickImage *loadImageInternal(KuickFile *file);
+  void stepBrightnessInternal(int b);
+  void stepContrastInternal(int c);
+  void stepGammaInternal(int g);
+
+  void setImageModifier();
+
   bool 		isAutoRendering;
+  bool 		myUseModifications;
   int 		myMaxImageCache;
   QColor 	myBackgroundColor;
+  QLabel* imageWidget;
 
-
-protected slots:
+protected Q_SLOTS:
   bool 		cacheImage( KuickFile *file );
   void 		setBusyCursor();
   void 		restoreCursor();
 
-
-signals:
+Q_SIGNALS:
   void 		sigImageError( const KuickFile * file, const QString& );
 
 };
