@@ -18,29 +18,31 @@
 
 #include "kuickurlwidget.h"
 
-#include <KRun>
+#include <KIO/OpenUrlJob>
 
 #include <QUrl>
 
 
-KuickUrlWidget::KuickUrlWidget(QWidget* parent) : KUrlLabel(parent)
+KuickUrlWidget::KuickUrlWidget(QWidget *parent) : KUrlLabel(parent)
 {
-    connect(this, SIGNAL(leftClickedUrl()), SLOT(run()));
+    connect(this, QOverload<>::of(&KUrlLabel::leftClickedUrl), this, &KuickUrlWidget::run);
     setUseTips(true);
 }
 
-KuickUrlWidget::KuickUrlWidget(const QString& text, QWidget *parent)
+KuickUrlWidget::KuickUrlWidget(const QString &text, QWidget *parent)
     : KUrlLabel( parent )
 {
     setText( text );
-    connect( this, SIGNAL( leftClickedUrl() ), SLOT( run() ));
+    connect(this, QOverload<>::of(&KUrlLabel::leftClickedUrl), this, &KuickUrlWidget::run);
     setUseTips( true );
 }
 
 void KuickUrlWidget::run()
 {
-    QUrl ku( url() );
-    if ( ku.isValid() ) {
-	(void) new KRun( ku, this );
-    }
+	const QUrl ku(url());
+	if(ku.isValid()) {
+		auto job = new KIO::OpenUrlJob(ku, this);
+		job->start();
+		// the KJob instance auto-deletes itself
+	}
 }
