@@ -22,11 +22,12 @@
 #include <QApplication>
 #include <QCommandLineParser>
 
+#include "imlib.h"
 #include "kuickshow.h"
 #include "version.h"
 
 
-extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
+int main(int argc, char** argv)
 {
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("kuickshow");
@@ -39,7 +40,7 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
         KAboutLicense::GPL,
         i18n("(c) 1998-2009, Carsten Pfeiffer"),
         QString(),
-        QStringLiteral("http://devel-home.kde.org/~pfeiffer/")
+        QStringLiteral(HOMEPAGE_URL)
     );
 
     about.addAuthor(i18n("Carsten Pfeiffer"), QString(), QStringLiteral("pfeiffer@kde.org"),
@@ -47,10 +48,11 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
     about.addCredit(i18n("Rober Hamberger"), QString(), QStringLiteral("rh474@bingo-ev.de"));
     about.addCredit(i18n("Thorsten Scheuermann"), QString(), QStringLiteral("uddn@rz.uni-karlsruhe.de"));
 
+    ImageLibrary::get()->addAboutData(about);
+
     KAboutData::setApplicationData(about);
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kuickshow")));
 
-
     QCommandLineParser parser;
     about.setupCommandLine(&parser);
 
@@ -63,12 +65,11 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
     // the parser is needed in KuickShow::KuickShow()
     app.setProperty("cmdlineParser", QVariant::fromValue<void *>(&parser));
 
-
-    if ( app.isSessionRestored() )
-	RESTORE( KuickShow )
-    else {
-	(void) new KuickShow( "kuickshow" );
-    }
+	if(app.isSessionRestored()) {
+		kRestoreMainWindows<KuickShow>();
+	} else {
+		(void) new KuickShow("kuickshow");
+	}
 
     return app.exec();
 }
