@@ -21,19 +21,20 @@
 
 #include <QWidget>
 
-class KuickData;
+class KuickConfig;
 namespace Ui { class SlideShowWidget; }
 
 
 class SlideShowWidget : public QWidget
 {
     Q_OBJECT
-public:
-    SlideShowWidget( QWidget *parent );
-    ~SlideShowWidget();
 
-    virtual void loadSettings( const KuickData& data );
-    virtual void applySettings( KuickData& data );
+public:
+    explicit SlideShowWidget( QWidget *parent );
+    virtual ~SlideShowWidget();
+
+    void 		loadSettings(const KuickConfig* config = nullptr);
+    void 		applySettings();
 
 private:
     Ui::SlideShowWidget* ui;
